@@ -1,6 +1,9 @@
 PKG_DATA_DIR = "/usr/share/uwsm"
 PROJECT_NAME = "uwsm"
-PROJECT_VERSION = "0.23.3"
+PROJECT_VERSION = "0.24.0"
 BIN_NAME = "uwsm"
 BIN_PATH = "/usr/bin/uwsm"
+SH_BIN = "sh"
+WAITPID_BIN = "waitpid"
+WHIPTAIL_BIN = "whiptail"
 STATIC_UNITS = "True"
